@@ -41,7 +41,7 @@
  *
  * Since: 2017.4
  */
-#define OSTREE_RELEASE_VERSION (2)
+#define OSTREE_RELEASE_VERSION (6)
 
 /**
  * OSTREE_VERSION
@@ -50,7 +50,7 @@
  *
  * Since: 2017.4
  */
-#define OSTREE_VERSION (2023.2)
+#define OSTREE_VERSION (2023.6)
 
 /**
  * OSTREE_VERSION_S:
@@ -60,7 +60,7 @@
  *
  * Since: 2017.4
  */
-#define OSTREE_VERSION_S "2023.2"
+#define OSTREE_VERSION_S "2023.6"
 
 #define OSTREE_ENCODE_VERSION(year,release) \
         ((year) << 16 | (release))
@@ -99,5 +99,5 @@
  * Since: 2019.3
  */
 #ifndef __GI_SCANNER__
-#define OSTREE_BUILT_FEATURES "libcurl libsoup gpgme sign-ed25519 ex-fsverity libarchive openssl avahi libmount systemd release p2p"
+#define OSTREE_BUILT_FEATURES "inode64 libcurl libsoup gpgme composefs ex-fsverity libarchive openssl sign-ed25519 avahi libmount systemd release p2p"
 #endif
